@@ -1,15 +1,17 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 from .spectral import *
 from .models import *
-from .lcio import *
+from .io import *
 from .snanaio import *
-from .plotting import *
 from .fitting import *
-from .typing import *
-from .extinction import *
-from .photometric_data import *
+from .extmap import *
+from .simulation import *
 from . import registry
 from . import _builtin
+try:
+    from plotting import *
+except ImportError:
+    pass
 
 #this indicates whether or not we are in the package's setup.py
 try:
