@@ -2,5 +2,5 @@ from astropy.utils.data import REMOTE_TIMEOUT
 
 REMOTE_TIMEOUT.set(10.)
 import bandpasses
-import models
+import sources
 import magsystems
